@@ -58,9 +58,9 @@ static const gchar *gda_freetds_provider_get_database (GdaServerProvider *provid
 static gboolean gda_freetds_provider_change_database (GdaServerProvider *provider,
                                                       GdaConnection *cnc,
                                                       const gchar *name);
-static gboolean gda_freetds_provider_create_database (GdaServerProvider *provider,
-                                                      GdaConnection *cnc,
-                                                      const gchar *name);
+static gboolean gda_freetds_provider_create_database_cnc (GdaServerProvider *provider,
+                                                          GdaConnection *cnc,
+                                                          const gchar *name);
 static gboolean gda_freetds_provider_drop_database (GdaServerProvider *provider,
                                                     GdaConnection *cnc,
                                                     const gchar *name);
@@ -247,7 +247,7 @@ gda_freetds_provider_open_connection (GdaServerProvider *provider,
 	if (t_port)
 		tds_set_port(tds_cnc->login, atoi(t_port));
 	
-	tds_set_charset(tds_cnc->login, "iso_1");
+	tds_set_client_charset(tds_cnc->login, "iso_1");
 	tds_set_language(tds_cnc->login, "us_english");
 	tds_set_packet(tds_cnc->login, 512);
 
@@ -482,9 +482,9 @@ gda_freetds_provider_change_database (GdaServerProvider *provider,
 }
 
 static gboolean
-gda_freetds_provider_create_database (GdaServerProvider *provider,
-                                      GdaConnection *cnc,
-                                      const gchar *name)
+gda_freetds_provider_create_database_cnc (GdaServerProvider *provider,
+                                          GdaConnection *cnc,
+                                          const gchar *name)
 {
 	GdaFreeTDSProvider *tds_prov = (GdaFreeTDSProvider *) provider;
 
@@ -655,7 +655,7 @@ static const gchar
 
 	g_return_val_if_fail (GDA_IS_FREETDS_PROVIDER (tds_prov), NULL);
 
-	return VERSION;
+	return PACKAGE_VERSION;
 }
 
 static GdaDataModel
@@ -991,7 +991,7 @@ gda_freetds_provider_class_init (GdaFreeTDSProviderClass *klass)
 	provider_class->close_connection = gda_freetds_provider_close_connection;
 	provider_class->get_database = gda_freetds_provider_get_database;
 	provider_class->change_database = gda_freetds_provider_change_database;
-	provider_class->create_database = gda_freetds_provider_create_database;
+	provider_class->create_database_cnc = gda_freetds_provider_create_database_cnc;
 	provider_class->drop_database = gda_freetds_provider_drop_database;
 	provider_class->execute_command = gda_freetds_provider_execute_command;
 	provider_class->begin_transaction = gda_freetds_provider_begin_transaction;
