@@ -46,7 +46,7 @@ static void gda_mysql_recordset_init       (GdaMysqlRecordset *recset,
 static void gda_mysql_recordset_finalize   (GObject *object);
 
 static gint gda_mysql_recordset_get_n_rows			     (GdaDataModelBase *model);
-static GdaDataModelColumnAttributes *gda_mysql_recordset_describe_column (GdaDataModelBase *model, gint col);
+static GdaColumn *gda_mysql_recordset_describe_column (GdaDataModelBase *model, gint col);
 static const GdaRow *gda_mysql_recordset_get_row		     (GdaDataModelBase *model, gint row);
 static const GdaValue *gda_mysql_recordset_get_value_at		     (GdaDataModelBase *model, gint col, gint row);
 static gboolean gda_mysql_recordset_is_updatable		     (GdaDataModelBase *model);
@@ -129,26 +129,34 @@ fill_gda_value (GdaValue *gda_value, enum enum_field_types type, gchar *value,
 		gda_value_set_single (gda_value, atof (value));
 		break;
 	case FIELD_TYPE_LONG :
-		if (is_unsigned)
-			gda_value_set_uinteger (gda_value, atol (value));
+		if (is_unsigned) {
+			gda_value_set_uinteger (gda_value, strtoul (value, NULL, 0));
+			break;
+		}
 	case FIELD_TYPE_YEAR :
 		gda_value_set_integer (gda_value, atol (value));
 		break;
 	case FIELD_TYPE_LONGLONG :
 	case FIELD_TYPE_INT24 :
-		if (is_unsigned)
-			gda_value_set_biguint (gda_value, atoll (value));
-		gda_value_set_bigint (gda_value, atoll (value));
+		if (is_unsigned) {
+			gda_value_set_biguint (gda_value, strtoull (value, NULL, 0));
+		} else {
+			gda_value_set_bigint (gda_value, atoll (value));
+		}
 		break;
 	case FIELD_TYPE_SHORT :
-		if (is_unsigned)
+		if (is_unsigned) {
 			gda_value_set_smalluint (gda_value, atoi (value));
-		gda_value_set_smallint (gda_value, atoi (value));
+		} else {
+			gda_value_set_smallint (gda_value, atoi (value));
+		}
 		break;
 	case FIELD_TYPE_TINY :
-		if (is_unsigned)
+		if (is_unsigned) {
 			gda_value_set_tinyuint (gda_value, atoi (value));
-		gda_value_set_tinyint (gda_value, atoi (value));
+		} else {
+			gda_value_set_tinyint (gda_value, atoi (value));
+		}
 		break;
 	case FIELD_TYPE_TINY_BLOB :
 	case FIELD_TYPE_MEDIUM_BLOB :
@@ -255,13 +263,13 @@ gda_mysql_recordset_get_n_rows (GdaDataModelBase *model)
 		return GDA_DATA_MODEL_BASE_CLASS (parent_class)->get_n_rows (model);
 }
 
-static GdaDataModelColumnAttributes *
+static GdaColumn *
 gda_mysql_recordset_describe_column (GdaDataModelBase *model, gint col)
 {
 	GdaMysqlRecordset *recset = (GdaMysqlRecordset *) model;
 	GdaMysqlRecordsetPrivate *priv_data;
 	gint field_count;
-	GdaDataModelColumnAttributes *attrs;
+	GdaColumn *attrs;
 	MYSQL_FIELD *mysql_field;
 
 	g_return_val_if_fail (GDA_IS_MYSQL_RECORDSET (recset), NULL);
@@ -274,7 +282,7 @@ gda_mysql_recordset_describe_column (GdaDataModelBase *model, gint col)
 		return NULL;
 	}
 
-	/* create the GdaDataModelColumnAttributes to be returned */
+	/* create the GdaColumn to be returned */
 	field_count = mysql_num_fields (priv_data->mysql_res);
 	if (col >= field_count)
 		return NULL;
@@ -283,24 +291,24 @@ gda_mysql_recordset_describe_column (GdaDataModelBase *model, gint col)
 	if (!mysql_field)
 		return NULL;
 
-	attrs = gda_data_model_column_attributes_new ();
+	attrs = gda_column_new ();
 
 	if (mysql_field->name)
-		gda_data_model_column_attributes_set_name (attrs, mysql_field->name);
-	gda_data_model_column_attributes_set_defined_size (attrs, mysql_field->length);
-	gda_data_model_column_attributes_set_table (attrs, mysql_field->table);
-	/* gda_data_model_column_attributes_set_caption(attrs, ); */
-	gda_data_model_column_attributes_set_scale (attrs, mysql_field->decimals);
-	gda_data_model_column_attributes_set_gdatype (attrs, gda_mysql_type_to_gda (mysql_field->type,
+		gda_column_set_name (attrs, mysql_field->name);
+	gda_column_set_defined_size (attrs, mysql_field->length);
+	gda_column_set_table (attrs, mysql_field->table);
+	/* gda_column_set_caption(attrs, ); */
+	gda_column_set_scale (attrs, mysql_field->decimals);
+	gda_column_set_gdatype (attrs, gda_mysql_type_to_gda (mysql_field->type,
 									mysql_field->flags & UNSIGNED_FLAG));
-	gda_data_model_column_attributes_set_allow_null (attrs, !IS_NOT_NULL (mysql_field->flags));
-	gda_data_model_column_attributes_set_primary_key (attrs, IS_PRI_KEY (mysql_field->flags));
-	gda_data_model_column_attributes_set_unique_key (attrs, mysql_field->flags & UNIQUE_KEY_FLAG);
-	/* gda_data_model_column_attributes_set_references(attrs, ); */
-	gda_data_model_column_attributes_set_auto_increment (attrs, mysql_field->flags & AUTO_INCREMENT_FLAG);
+	gda_column_set_allow_null (attrs, !IS_NOT_NULL (mysql_field->flags));
+	gda_column_set_primary_key (attrs, IS_PRI_KEY (mysql_field->flags));
+	gda_column_set_unique_key (attrs, mysql_field->flags & UNIQUE_KEY_FLAG);
+	/* gda_column_set_references(attrs, ); */
+	gda_column_set_auto_increment (attrs, mysql_field->flags & AUTO_INCREMENT_FLAG);
 	/* attrs->auto_increment_start */
 	/* attrs->auto_increment_step  */
-	gda_data_model_column_attributes_set_position (attrs, col);
+	gda_column_set_position (attrs, col);
 
 	return attrs;
 }
@@ -496,7 +504,12 @@ gda_mysql_recordset_append_row (GdaDataModelBase *model, GdaRow *row)
 		sql = g_string_append (sql, column_name);
 		sql = g_string_append (sql, "`");
 
-		sql_value = g_string_append (sql_value, gda_mysql_value_to_sql_string (gda_row_get_value ((GdaRow *) row, i)));
+		sql_value = g_string_append (sql_value, 
+			gda_mysql_provider_value_to_sql_string ( 	 
+				NULL, 	 
+				priv_data->cnc, 	 
+				gda_row_get_value ((GdaRow *) row, i)) 	 
+                 );
 	}
 
 	/* concatenate SQL statement */
@@ -531,7 +544,7 @@ gda_mysql_recordset_remove_row (GdaDataModelBase *model, const GdaRow *row)
 	GdaMysqlRecordset *recset = (GdaMysqlRecordset *) model;
 	GdaMysqlRecordsetPrivate *priv_data;
 	GdaRow *row_list;
-	GdaDataModelColumnAttributes *attrs;
+	GdaColumn *attrs;
 	MYSQL *mysql;
 	MYSQL_FIELD *mysql_field;
 	gint i, fetched_rows, rc, colnum, uk;
@@ -610,11 +623,14 @@ gda_mysql_recordset_remove_row (GdaDataModelBase *model, const GdaRow *row)
 		else
 			column_name = gda_data_model_get_column_title (GDA_DATA_MODEL (model), colnum);
 
-		gchar *curval = gda_mysql_value_to_sql_string (gda_row_get_value ((GdaRow *) row, colnum));
-
+		gchar *curval = gda_mysql_provider_value_to_sql_string (
+				NULL, 	 
+				priv_data->cnc, 	 
+				gda_row_get_value ((GdaRow *) row, colnum) 	 
+     		);
 		/* unique column: we will use it as an index */
-		if (gda_field_attributes_get_primary_key (attrs) ||
-		    gda_field_attributes_get_unique_key (attrs))
+		if (gda_column_get_primary_key (attrs) ||
+		    gda_column_get_unique_key (attrs))
 		{
 			/* fills the 'where' part of the update command */
 			if (colnum != 0)
@@ -630,7 +646,7 @@ gda_mysql_recordset_remove_row (GdaDataModelBase *model, const GdaRow *row)
 		}
 
 		g_free (curval);
-		gda_field_attributes_free (attrs);
+		gda_column_free (attrs);
 	}
 
 	if (uk == 0) {
@@ -682,7 +698,7 @@ gda_mysql_recordset_update_row (GdaDataModelBase *model, const GdaRow *row)
 	MYSQL *mysql;
 	MYSQL_FIELD *mysql_field;
 	MYSQL_ROW mysql_row;
-	GdaDataModelColumnAttributes *attrs;
+	GdaColumn *attrs;
 
 	g_return_val_if_fail (GDA_IS_MYSQL_RECORDSET (recset), FALSE);
 	g_return_val_if_fail (row != NULL, FALSE);
@@ -747,8 +763,8 @@ gda_mysql_recordset_update_row (GdaDataModelBase *model, const GdaRow *row)
 
 		/* unique column: we won't update it, but we will use it as
 		   an index */
-		if (gda_data_model_column_attributes_get_primary_key (attrs) ||
-		    gda_data_model_column_attributes_get_unique_key (attrs)) 
+		if (gda_column_get_primary_key (attrs) ||
+		    gda_column_get_unique_key (attrs)) 
 		{
 			/* checks if it hasn't be modified anyway */
 			if (oldval == NULL ||
@@ -779,7 +795,7 @@ gda_mysql_recordset_update_row (GdaDataModelBase *model, const GdaRow *row)
 		}
 
 		g_free (newval);
-		gda_data_model_column_attributes_free (attrs);
+		gda_column_free (attrs);
 	}
 
 	if (uk == 0) {
@@ -870,11 +886,12 @@ gda_mysql_recordset_new (GdaConnection *cnc, MYSQL_RES *mysql_res, MYSQL *mysql)
 	model->priv->cnc = cnc;
 	model->priv->row_sync = FALSE;
 	model->priv->ncolumns = 0;
-	if (mysql_res == NULL)
+	if (mysql_res == NULL) {
 		model->priv->mysql_res_rows = mysql_affected_rows (mysql);
-	else
+		return model;
+	} else {
 		model->priv->mysql_res_rows = mysql_num_rows (model->priv->mysql_res);
-
+	}
 	mysql_fields = mysql_fetch_fields (model->priv->mysql_res);
 	if (mysql_fields != NULL) {
 		gint i;
