@@ -1,5 +1,5 @@
 /* GDA Postgres Provider
- * Copyright (C) 1998-2002 The GNOME Foundation
+ * Copyright (C) 1998 - 2005 The GNOME Foundation
  *
  * AUTHORS:
  *         Vivien Malerba <malerba@gnome-db.org>
@@ -21,13 +21,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <libgda/gda-config.h>
 #include <libgda/gda-intl.h>
 #include "gda-sqlite-provider.h"
 
-const gchar *plugin_get_name (void);
-const gchar *plugin_get_description (void);
-GList *plugin_get_connection_params (void);
+const gchar       *plugin_get_name (void);
+const gchar       *plugin_get_description (void);
+GList             *plugin_get_connection_params (void);
+gchar             *plugin_get_dsn_spec (void);
 GdaServerProvider *plugin_create_provider (void);
 
 const gchar *
@@ -55,6 +55,19 @@ plugin_get_connection_params (void)
 	return list;
 }
 
+gchar *
+plugin_get_dsn_spec (void)
+{
+	gchar *specs, *file;
+	gint len;
+
+	file = g_build_filename (LIBGDA_DATA_DIR, "sqlite_specs_dsn.xml", NULL);
+	if (g_file_get_contents (file, &specs, &len, NULL)) 
+		return specs;
+	else
+		return NULL;
+}
+
 GdaServerProvider *
 plugin_create_provider (void)
 {
